time

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 4, 2024 License: Apache-2.0 Imports: 6 Imported by: 9

Documentation

Overview

A Pulumi package for creating and managing Time resources

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Offset

type Offset struct {
	pulumi.CustomResourceState

	// Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.
	BaseRfc3339 pulumi.StringOutput `pulumi:"baseRfc3339"`
	// Number day of offset timestamp.
	Day pulumi.IntOutput `pulumi:"day"`
	// Number hour of offset timestamp.
	Hour pulumi.IntOutput `pulumi:"hour"`
	// Number minute of offset timestamp.
	Minute pulumi.IntOutput `pulumi:"minute"`
	// Number month of offset timestamp.
	Month pulumi.IntOutput `pulumi:"month"`
	// Number of days to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetDays pulumi.IntPtrOutput `pulumi:"offsetDays"`
	// Number of hours to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetHours pulumi.IntPtrOutput `pulumi:"offsetHours"`
	// Number of minutes to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetMinutes pulumi.IntPtrOutput `pulumi:"offsetMinutes"`
	// Number of months to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetMonths pulumi.IntPtrOutput `pulumi:"offsetMonths"`
	// Number of seconds to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetSeconds pulumi.IntPtrOutput `pulumi:"offsetSeconds"`
	// Number of years to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetYears pulumi.IntPtrOutput `pulumi:"offsetYears"`
	// RFC3339 format of the offset timestamp, e.g. `2020-02-12T06:36:13Z`.
	Rfc3339 pulumi.StringOutput `pulumi:"rfc3339"`
	// Number second of offset timestamp.
	Second pulumi.IntOutput `pulumi:"second"`
	// Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. See the main provider documentation for more information.
	Triggers pulumi.StringMapOutput `pulumi:"triggers"`
	// Number of seconds since epoch time, e.g. `1581489373`.
	Unix pulumi.IntOutput `pulumi:"unix"`
	// Number year of offset timestamp.
	Year pulumi.IntOutput `pulumi:"year"`
}

## Example Usage

### Basic Usage

```go package main

import (

"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
"github.com/pulumiverse/pulumi-time/sdk/go/time"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		example, err := time.NewOffset(ctx, "example", &time.OffsetArgs{
			OffsetDays: pulumi.Int(7),
		})
		if err != nil {
			return err
		}
		ctx.Export("oneWeekFromNow", example.Rfc3339)
		return nil
	})
}

```

### Multiple Offsets Usage

```go package main

import (

"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
"github.com/pulumiverse/pulumi-time/sdk/go/time"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		example, err := time.NewOffset(ctx, "example", &time.OffsetArgs{
			OffsetYears:  pulumi.Int(1),
			OffsetMonths: pulumi.Int(1),
		})
		if err != nil {
			return err
		}
		ctx.Export("oneYearAndMonthFromNow", example.Rfc3339)
		return nil
	})
}

```

### Triggers Usage

```go package main

import (

"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/ec2"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
"github.com/pulumiverse/pulumi-time/sdk/go/time"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		amiUpdate, err := time.NewOffset(ctx, "amiUpdate", &time.OffsetArgs{
			Triggers: pulumi.StringMap{
				"ami_id": pulumi.Any(data.Aws_ami.Example.Id),
			},
			OffsetDays: pulumi.Int(7),
		})
		if err != nil {
			return err
		}
		_, err = ec2.NewInstance(ctx, "server", &ec2.InstanceArgs{
			Ami: pulumi.String(amiUpdate.Triggers.ApplyT(func(triggers map[string]string) (*string, error) {
				return &triggers.AmiId, nil
			}).(pulumi.StringPtrOutput)),
			Tags: pulumi.StringMap{
				"ExpirationTime": amiUpdate.Rfc3339,
			},
		})
		if err != nil {
			return err
		}
		return nil
	})
}

```

## Import

This resource can be imported using the base UTC RFC3339 timestamp and offset years, months, days, hours, minutes, and seconds, separated by commas (`,`), e.g.

```sh $ pulumi import time:index/offset:Offset example 2020-02-12T06:36:13Z,0,0,7,0,0,0 ```

The `triggers` argument cannot be imported.

func GetOffset

func GetOffset(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *OffsetState, opts ...pulumi.ResourceOption) (*Offset, error)

GetOffset gets an existing Offset resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewOffset

func NewOffset(ctx *pulumi.Context,
	name string, args *OffsetArgs, opts ...pulumi.ResourceOption) (*Offset, error)

NewOffset registers a new resource with the given unique name, arguments, and options.

func (*Offset) ElementType

func (*Offset) ElementType() reflect.Type

func (*Offset) ToOffsetOutput

func (i *Offset) ToOffsetOutput() OffsetOutput

func (*Offset) ToOffsetOutputWithContext

func (i *Offset) ToOffsetOutputWithContext(ctx context.Context) OffsetOutput

type OffsetArgs

type OffsetArgs struct {
	// Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.
	BaseRfc3339 pulumi.StringPtrInput
	// Number of days to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetDays pulumi.IntPtrInput
	// Number of hours to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetHours pulumi.IntPtrInput
	// Number of minutes to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetMinutes pulumi.IntPtrInput
	// Number of months to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetMonths pulumi.IntPtrInput
	// Number of seconds to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetSeconds pulumi.IntPtrInput
	// Number of years to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetYears pulumi.IntPtrInput
	// Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. See the main provider documentation for more information.
	Triggers pulumi.StringMapInput
}

The set of arguments for constructing a Offset resource.

func (OffsetArgs) ElementType

func (OffsetArgs) ElementType() reflect.Type

type OffsetArray

type OffsetArray []OffsetInput

func (OffsetArray) ElementType

func (OffsetArray) ElementType() reflect.Type

func (OffsetArray) ToOffsetArrayOutput

func (i OffsetArray) ToOffsetArrayOutput() OffsetArrayOutput

func (OffsetArray) ToOffsetArrayOutputWithContext

func (i OffsetArray) ToOffsetArrayOutputWithContext(ctx context.Context) OffsetArrayOutput

type OffsetArrayInput

type OffsetArrayInput interface {
	pulumi.Input

	ToOffsetArrayOutput() OffsetArrayOutput
	ToOffsetArrayOutputWithContext(context.Context) OffsetArrayOutput
}

OffsetArrayInput is an input type that accepts OffsetArray and OffsetArrayOutput values. You can construct a concrete instance of `OffsetArrayInput` via:

OffsetArray{ OffsetArgs{...} }

type OffsetArrayOutput

type OffsetArrayOutput struct{ *pulumi.OutputState }

func (OffsetArrayOutput) ElementType

func (OffsetArrayOutput) ElementType() reflect.Type

func (OffsetArrayOutput) Index

func (OffsetArrayOutput) ToOffsetArrayOutput

func (o OffsetArrayOutput) ToOffsetArrayOutput() OffsetArrayOutput

func (OffsetArrayOutput) ToOffsetArrayOutputWithContext

func (o OffsetArrayOutput) ToOffsetArrayOutputWithContext(ctx context.Context) OffsetArrayOutput

type OffsetInput

type OffsetInput interface {
	pulumi.Input

	ToOffsetOutput() OffsetOutput
	ToOffsetOutputWithContext(ctx context.Context) OffsetOutput
}

type OffsetMap

type OffsetMap map[string]OffsetInput

func (OffsetMap) ElementType

func (OffsetMap) ElementType() reflect.Type

func (OffsetMap) ToOffsetMapOutput

func (i OffsetMap) ToOffsetMapOutput() OffsetMapOutput

func (OffsetMap) ToOffsetMapOutputWithContext

func (i OffsetMap) ToOffsetMapOutputWithContext(ctx context.Context) OffsetMapOutput

type OffsetMapInput

type OffsetMapInput interface {
	pulumi.Input

	ToOffsetMapOutput() OffsetMapOutput
	ToOffsetMapOutputWithContext(context.Context) OffsetMapOutput
}

OffsetMapInput is an input type that accepts OffsetMap and OffsetMapOutput values. You can construct a concrete instance of `OffsetMapInput` via:

OffsetMap{ "key": OffsetArgs{...} }

type OffsetMapOutput

type OffsetMapOutput struct{ *pulumi.OutputState }

func (OffsetMapOutput) ElementType

func (OffsetMapOutput) ElementType() reflect.Type

func (OffsetMapOutput) MapIndex

func (OffsetMapOutput) ToOffsetMapOutput

func (o OffsetMapOutput) ToOffsetMapOutput() OffsetMapOutput

func (OffsetMapOutput) ToOffsetMapOutputWithContext

func (o OffsetMapOutput) ToOffsetMapOutputWithContext(ctx context.Context) OffsetMapOutput

type OffsetOutput

type OffsetOutput struct{ *pulumi.OutputState }

func (OffsetOutput) BaseRfc3339

func (o OffsetOutput) BaseRfc3339() pulumi.StringOutput

Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.

func (OffsetOutput) Day

func (o OffsetOutput) Day() pulumi.IntOutput

Number day of offset timestamp.

func (OffsetOutput) ElementType

func (OffsetOutput) ElementType() reflect.Type

func (OffsetOutput) Hour

func (o OffsetOutput) Hour() pulumi.IntOutput

Number hour of offset timestamp.

func (OffsetOutput) Minute

func (o OffsetOutput) Minute() pulumi.IntOutput

Number minute of offset timestamp.

func (OffsetOutput) Month

func (o OffsetOutput) Month() pulumi.IntOutput

Number month of offset timestamp.

func (OffsetOutput) OffsetDays

func (o OffsetOutput) OffsetDays() pulumi.IntPtrOutput

Number of days to offset the base timestamp. At least one of the 'offset_' arguments must be configured.

func (OffsetOutput) OffsetHours

func (o OffsetOutput) OffsetHours() pulumi.IntPtrOutput

Number of hours to offset the base timestamp. At least one of the 'offset_' arguments must be configured.

func (OffsetOutput) OffsetMinutes

func (o OffsetOutput) OffsetMinutes() pulumi.IntPtrOutput

Number of minutes to offset the base timestamp. At least one of the 'offset_' arguments must be configured.

func (OffsetOutput) OffsetMonths

func (o OffsetOutput) OffsetMonths() pulumi.IntPtrOutput

Number of months to offset the base timestamp. At least one of the 'offset_' arguments must be configured.

func (OffsetOutput) OffsetSeconds

func (o OffsetOutput) OffsetSeconds() pulumi.IntPtrOutput

Number of seconds to offset the base timestamp. At least one of the 'offset_' arguments must be configured.

func (OffsetOutput) OffsetYears

func (o OffsetOutput) OffsetYears() pulumi.IntPtrOutput

Number of years to offset the base timestamp. At least one of the 'offset_' arguments must be configured.

func (OffsetOutput) Rfc3339

func (o OffsetOutput) Rfc3339() pulumi.StringOutput

RFC3339 format of the offset timestamp, e.g. `2020-02-12T06:36:13Z`.

func (OffsetOutput) Second

func (o OffsetOutput) Second() pulumi.IntOutput

Number second of offset timestamp.

func (OffsetOutput) ToOffsetOutput

func (o OffsetOutput) ToOffsetOutput() OffsetOutput

func (OffsetOutput) ToOffsetOutputWithContext

func (o OffsetOutput) ToOffsetOutputWithContext(ctx context.Context) OffsetOutput

func (OffsetOutput) Triggers

func (o OffsetOutput) Triggers() pulumi.StringMapOutput

Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. See the main provider documentation for more information.

func (OffsetOutput) Unix

func (o OffsetOutput) Unix() pulumi.IntOutput

Number of seconds since epoch time, e.g. `1581489373`.

func (OffsetOutput) Year

func (o OffsetOutput) Year() pulumi.IntOutput

Number year of offset timestamp.

type OffsetState

type OffsetState struct {
	// Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.
	BaseRfc3339 pulumi.StringPtrInput
	// Number day of offset timestamp.
	Day pulumi.IntPtrInput
	// Number hour of offset timestamp.
	Hour pulumi.IntPtrInput
	// Number minute of offset timestamp.
	Minute pulumi.IntPtrInput
	// Number month of offset timestamp.
	Month pulumi.IntPtrInput
	// Number of days to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetDays pulumi.IntPtrInput
	// Number of hours to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetHours pulumi.IntPtrInput
	// Number of minutes to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetMinutes pulumi.IntPtrInput
	// Number of months to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetMonths pulumi.IntPtrInput
	// Number of seconds to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetSeconds pulumi.IntPtrInput
	// Number of years to offset the base timestamp. At least one of the 'offset_' arguments must be configured.
	OffsetYears pulumi.IntPtrInput
	// RFC3339 format of the offset timestamp, e.g. `2020-02-12T06:36:13Z`.
	Rfc3339 pulumi.StringPtrInput
	// Number second of offset timestamp.
	Second pulumi.IntPtrInput
	// Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. See the main provider documentation for more information.
	Triggers pulumi.StringMapInput
	// Number of seconds since epoch time, e.g. `1581489373`.
	Unix pulumi.IntPtrInput
	// Number year of offset timestamp.
	Year pulumi.IntPtrInput
}

func (OffsetState) ElementType

func (OffsetState) ElementType() reflect.Type

type Provider

type Provider struct {
	pulumi.ProviderResourceState
}

The provider type for the time package. By default, resources use package-wide configuration settings, however an explicit `Provider` instance may be created and passed during resource construction to achieve fine-grained programmatic control over provider settings. See the [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

func NewProvider

func NewProvider(ctx *pulumi.Context,
	name string, args *ProviderArgs, opts ...pulumi.ResourceOption) (*Provider, error)

NewProvider registers a new resource with the given unique name, arguments, and options.

func (*Provider) ElementType

func (*Provider) ElementType() reflect.Type

func (*Provider) ToProviderOutput

func (i *Provider) ToProviderOutput() ProviderOutput

func (*Provider) ToProviderOutputWithContext

func (i *Provider) ToProviderOutputWithContext(ctx context.Context) ProviderOutput

type ProviderArgs

type ProviderArgs struct {
}

The set of arguments for constructing a Provider resource.

func (ProviderArgs) ElementType

func (ProviderArgs) ElementType() reflect.Type

type ProviderInput

type ProviderInput interface {
	pulumi.Input

	ToProviderOutput() ProviderOutput
	ToProviderOutputWithContext(ctx context.Context) ProviderOutput
}

type ProviderOutput

type ProviderOutput struct{ *pulumi.OutputState }

func (ProviderOutput) ElementType

func (ProviderOutput) ElementType() reflect.Type

func (ProviderOutput) ToProviderOutput

func (o ProviderOutput) ToProviderOutput() ProviderOutput

func (ProviderOutput) ToProviderOutputWithContext

func (o ProviderOutput) ToProviderOutputWithContext(ctx context.Context) ProviderOutput

type Rotating

type Rotating struct {
	pulumi.CustomResourceState

	// Number day of timestamp.
	Day pulumi.IntOutput `pulumi:"day"`
	// Number hour of timestamp.
	Hour pulumi.IntOutput `pulumi:"hour"`
	// Number minute of timestamp.
	Minute pulumi.IntOutput `pulumi:"minute"`
	// Number month of timestamp.
	Month pulumi.IntOutput `pulumi:"month"`
	// Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.
	Rfc3339 pulumi.StringOutput `pulumi:"rfc3339"`
	// Number of days to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationDays pulumi.IntPtrOutput `pulumi:"rotationDays"`
	// Number of hours to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationHours pulumi.IntPtrOutput `pulumi:"rotationHours"`
	// Number of minutes to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationMinutes pulumi.IntPtrOutput `pulumi:"rotationMinutes"`
	// Number of months to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationMonths pulumi.IntPtrOutput `pulumi:"rotationMonths"`
	// Configure the rotation timestamp with an [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format of the offset timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationRfc3339 pulumi.StringOutput `pulumi:"rotationRfc3339"`
	// Number of years to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationYears pulumi.IntPtrOutput `pulumi:"rotationYears"`
	// Number second of timestamp.
	Second pulumi.IntOutput `pulumi:"second"`
	// Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. These conditions recreate the resource in addition to other rotation arguments. See the main provider documentation for more information.
	Triggers pulumi.StringMapOutput `pulumi:"triggers"`
	// Number of seconds since epoch time, e.g. `1581489373`.
	Unix pulumi.IntOutput `pulumi:"unix"`
	// Number year of timestamp.
	Year pulumi.IntOutput `pulumi:"year"`
}

## Example Usage

### Basic Usage

```go package main

import (

"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
"github.com/pulumiverse/pulumi-time/sdk/go/time"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := time.NewRotating(ctx, "example", &time.RotatingArgs{
			RotationDays: pulumi.Int(30),
		})
		if err != nil {
			return err
		}
		return nil
	})
}

```

## Import

This resource can be imported using the base UTC RFC3339 value and rotation years, months, days, hours, and minutes, separated by commas (`,`), e.g. for 30 days

```sh $ pulumi import time:index/rotating:Rotating example 2020-02-12T06:36:13Z,0,0,30,0,0 ```

Otherwise, to import with the rotation RFC3339 value, the base UTC RFC3339 value and rotation UTC RFC3339 value, separated by commas (`,`), e.g.

```sh $ pulumi import time:index/rotating:Rotating example 2020-02-12T06:36:13Z,2020-02-13T06:36:13Z ```

The `triggers` argument cannot be imported.

func GetRotating

func GetRotating(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *RotatingState, opts ...pulumi.ResourceOption) (*Rotating, error)

GetRotating gets an existing Rotating resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewRotating

func NewRotating(ctx *pulumi.Context,
	name string, args *RotatingArgs, opts ...pulumi.ResourceOption) (*Rotating, error)

NewRotating registers a new resource with the given unique name, arguments, and options.

func (*Rotating) ElementType

func (*Rotating) ElementType() reflect.Type

func (*Rotating) ToRotatingOutput

func (i *Rotating) ToRotatingOutput() RotatingOutput

func (*Rotating) ToRotatingOutputWithContext

func (i *Rotating) ToRotatingOutputWithContext(ctx context.Context) RotatingOutput

type RotatingArgs

type RotatingArgs struct {
	// Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.
	Rfc3339 pulumi.StringPtrInput
	// Number of days to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationDays pulumi.IntPtrInput
	// Number of hours to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationHours pulumi.IntPtrInput
	// Number of minutes to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationMinutes pulumi.IntPtrInput
	// Number of months to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationMonths pulumi.IntPtrInput
	// Configure the rotation timestamp with an [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format of the offset timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationRfc3339 pulumi.StringPtrInput
	// Number of years to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationYears pulumi.IntPtrInput
	// Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. These conditions recreate the resource in addition to other rotation arguments. See the main provider documentation for more information.
	Triggers pulumi.StringMapInput
}

The set of arguments for constructing a Rotating resource.

func (RotatingArgs) ElementType

func (RotatingArgs) ElementType() reflect.Type

type RotatingArray

type RotatingArray []RotatingInput

func (RotatingArray) ElementType

func (RotatingArray) ElementType() reflect.Type

func (RotatingArray) ToRotatingArrayOutput

func (i RotatingArray) ToRotatingArrayOutput() RotatingArrayOutput

func (RotatingArray) ToRotatingArrayOutputWithContext

func (i RotatingArray) ToRotatingArrayOutputWithContext(ctx context.Context) RotatingArrayOutput

type RotatingArrayInput

type RotatingArrayInput interface {
	pulumi.Input

	ToRotatingArrayOutput() RotatingArrayOutput
	ToRotatingArrayOutputWithContext(context.Context) RotatingArrayOutput
}

RotatingArrayInput is an input type that accepts RotatingArray and RotatingArrayOutput values. You can construct a concrete instance of `RotatingArrayInput` via:

RotatingArray{ RotatingArgs{...} }

type RotatingArrayOutput

type RotatingArrayOutput struct{ *pulumi.OutputState }

func (RotatingArrayOutput) ElementType

func (RotatingArrayOutput) ElementType() reflect.Type

func (RotatingArrayOutput) Index

func (RotatingArrayOutput) ToRotatingArrayOutput

func (o RotatingArrayOutput) ToRotatingArrayOutput() RotatingArrayOutput

func (RotatingArrayOutput) ToRotatingArrayOutputWithContext

func (o RotatingArrayOutput) ToRotatingArrayOutputWithContext(ctx context.Context) RotatingArrayOutput

type RotatingInput

type RotatingInput interface {
	pulumi.Input

	ToRotatingOutput() RotatingOutput
	ToRotatingOutputWithContext(ctx context.Context) RotatingOutput
}

type RotatingMap

type RotatingMap map[string]RotatingInput

func (RotatingMap) ElementType

func (RotatingMap) ElementType() reflect.Type

func (RotatingMap) ToRotatingMapOutput

func (i RotatingMap) ToRotatingMapOutput() RotatingMapOutput

func (RotatingMap) ToRotatingMapOutputWithContext

func (i RotatingMap) ToRotatingMapOutputWithContext(ctx context.Context) RotatingMapOutput

type RotatingMapInput

type RotatingMapInput interface {
	pulumi.Input

	ToRotatingMapOutput() RotatingMapOutput
	ToRotatingMapOutputWithContext(context.Context) RotatingMapOutput
}

RotatingMapInput is an input type that accepts RotatingMap and RotatingMapOutput values. You can construct a concrete instance of `RotatingMapInput` via:

RotatingMap{ "key": RotatingArgs{...} }

type RotatingMapOutput

type RotatingMapOutput struct{ *pulumi.OutputState }

func (RotatingMapOutput) ElementType

func (RotatingMapOutput) ElementType() reflect.Type

func (RotatingMapOutput) MapIndex

func (RotatingMapOutput) ToRotatingMapOutput

func (o RotatingMapOutput) ToRotatingMapOutput() RotatingMapOutput

func (RotatingMapOutput) ToRotatingMapOutputWithContext

func (o RotatingMapOutput) ToRotatingMapOutputWithContext(ctx context.Context) RotatingMapOutput

type RotatingOutput

type RotatingOutput struct{ *pulumi.OutputState }

func (RotatingOutput) Day

Number day of timestamp.

func (RotatingOutput) ElementType

func (RotatingOutput) ElementType() reflect.Type

func (RotatingOutput) Hour

func (o RotatingOutput) Hour() pulumi.IntOutput

Number hour of timestamp.

func (RotatingOutput) Minute

func (o RotatingOutput) Minute() pulumi.IntOutput

Number minute of timestamp.

func (RotatingOutput) Month

func (o RotatingOutput) Month() pulumi.IntOutput

Number month of timestamp.

func (RotatingOutput) Rfc3339

func (o RotatingOutput) Rfc3339() pulumi.StringOutput

Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.

func (RotatingOutput) RotationDays

func (o RotatingOutput) RotationDays() pulumi.IntPtrOutput

Number of days to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.

func (RotatingOutput) RotationHours

func (o RotatingOutput) RotationHours() pulumi.IntPtrOutput

Number of hours to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.

func (RotatingOutput) RotationMinutes

func (o RotatingOutput) RotationMinutes() pulumi.IntPtrOutput

Number of minutes to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.

func (RotatingOutput) RotationMonths

func (o RotatingOutput) RotationMonths() pulumi.IntPtrOutput

Number of months to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.

func (RotatingOutput) RotationRfc3339

func (o RotatingOutput) RotationRfc3339() pulumi.StringOutput

Configure the rotation timestamp with an [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format of the offset timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.

func (RotatingOutput) RotationYears

func (o RotatingOutput) RotationYears() pulumi.IntPtrOutput

Number of years to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.

func (RotatingOutput) Second

func (o RotatingOutput) Second() pulumi.IntOutput

Number second of timestamp.

func (RotatingOutput) ToRotatingOutput

func (o RotatingOutput) ToRotatingOutput() RotatingOutput

func (RotatingOutput) ToRotatingOutputWithContext

func (o RotatingOutput) ToRotatingOutputWithContext(ctx context.Context) RotatingOutput

func (RotatingOutput) Triggers

func (o RotatingOutput) Triggers() pulumi.StringMapOutput

Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. These conditions recreate the resource in addition to other rotation arguments. See the main provider documentation for more information.

func (RotatingOutput) Unix

func (o RotatingOutput) Unix() pulumi.IntOutput

Number of seconds since epoch time, e.g. `1581489373`.

func (RotatingOutput) Year

func (o RotatingOutput) Year() pulumi.IntOutput

Number year of timestamp.

type RotatingState

type RotatingState struct {
	// Number day of timestamp.
	Day pulumi.IntPtrInput
	// Number hour of timestamp.
	Hour pulumi.IntPtrInput
	// Number minute of timestamp.
	Minute pulumi.IntPtrInput
	// Number month of timestamp.
	Month pulumi.IntPtrInput
	// Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.
	Rfc3339 pulumi.StringPtrInput
	// Number of days to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationDays pulumi.IntPtrInput
	// Number of hours to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationHours pulumi.IntPtrInput
	// Number of minutes to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationMinutes pulumi.IntPtrInput
	// Number of months to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationMonths pulumi.IntPtrInput
	// Configure the rotation timestamp with an [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format of the offset timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationRfc3339 pulumi.StringPtrInput
	// Number of years to add to the base timestamp to configure the rotation timestamp. When the current time has passed the rotation timestamp, the resource will trigger recreation. At least one of the 'rotation_' arguments must be configured.
	RotationYears pulumi.IntPtrInput
	// Number second of timestamp.
	Second pulumi.IntPtrInput
	// Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. These conditions recreate the resource in addition to other rotation arguments. See the main provider documentation for more information.
	Triggers pulumi.StringMapInput
	// Number of seconds since epoch time, e.g. `1581489373`.
	Unix pulumi.IntPtrInput
	// Number year of timestamp.
	Year pulumi.IntPtrInput
}

func (RotatingState) ElementType

func (RotatingState) ElementType() reflect.Type

type Sleep added in v0.0.16

type Sleep struct {
	pulumi.CustomResourceState

	// [Time duration](https://golang.org/pkg/time/#ParseDuration) to delay resource creation. For example, `30s` for 30 seconds or `5m` for 5 minutes. Updating this value by itself will not trigger a delay.
	CreateDuration  pulumi.StringPtrOutput `pulumi:"createDuration"`
	DestroyDuration pulumi.StringPtrOutput `pulumi:"destroyDuration"`
	// (Optional) Arbitrary map of values that, when changed, will run any creation or destroy delays again. See the main provider documentation for more information.
	Triggers pulumi.StringMapOutput `pulumi:"triggers"`
}

## Example Usage

### Delay Create Usage

```go package main

import (

"github.com/pulumi/pulumi-null/sdk/go/null"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
"github.com/pulumiverse/pulumi-time/sdk/go/time"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		// This resource will destroy (potentially immediately) after null_resource.next
		previous, err := null.NewResource(ctx, "previous", nil)
		if err != nil {
			return err
		}
		wait30Seconds, err := time.NewSleep(ctx, "wait30Seconds", &time.SleepArgs{
			CreateDuration: pulumi.String("30s"),
		}, pulumi.DependsOn([]pulumi.Resource{
			previous,
		}))
		if err != nil {
			return err
		}
		// This resource will create (at least) 30 seconds after null_resource.previous
		_, err = null.NewResource(ctx, "next", nil, pulumi.DependsOn([]pulumi.Resource{
			wait30Seconds,
		}))
		if err != nil {
			return err
		}
		return nil
	})
}

```

### Delay Destroy Usage

```go package main

import (

"github.com/pulumi/pulumi-null/sdk/go/null"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
"github.com/pulumiverse/pulumi-time/sdk/go/time"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		// This resource will destroy (at least) 30 seconds after null_resource.next
		previous, err := null.NewResource(ctx, "previous", nil)
		if err != nil {
			return err
		}
		wait30Seconds, err := time.NewSleep(ctx, "wait30Seconds", &time.SleepArgs{
			DestroyDuration: pulumi.String("30s"),
		}, pulumi.DependsOn([]pulumi.Resource{
			previous,
		}))
		if err != nil {
			return err
		}
		// This resource will create (potentially immediately) after null_resource.previous
		_, err = null.NewResource(ctx, "next", nil, pulumi.DependsOn([]pulumi.Resource{
			wait30Seconds,
		}))
		if err != nil {
			return err
		}
		return nil
	})
}

```

### Triggers Usage

```go package main

import (

"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/ram"
"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/rds"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
"github.com/pulumiverse/pulumi-time/sdk/go/time"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		exampleResourceAssociation, err := ram.NewResourceAssociation(ctx, "exampleResourceAssociation", &ram.ResourceAssociationArgs{
			ResourceArn:      pulumi.Any(aws_subnet.Example.Arn),
			ResourceShareArn: pulumi.Any(aws_ram_resource_share.Example.Arn),
		})
		if err != nil {
			return err
		}
		// AWS resources shared via Resource Access Manager can take a few seconds to
		// propagate across AWS accounts after RAM returns a successful association.
		ramResourcePropagation, err := time.NewSleep(ctx, "ramResourcePropagation", &time.SleepArgs{
			CreateDuration: pulumi.String("60s"),
			Triggers: pulumi.StringMap{
				"subnet_arn": exampleResourceAssociation.ResourceArn,
				"subnet_id":  pulumi.Any(aws_subnet.Example.Id),
			},
		})
		if err != nil {
			return err
		}
		_, err = rds.NewSubnetGroup(ctx, "exampleSubnetGroup", &rds.SubnetGroupArgs{
			SubnetIds: pulumi.StringArray{
				pulumi.String(ramResourcePropagation.Triggers.ApplyT(func(triggers map[string]string) (*string, error) {
					return &triggers.Subnet_id, nil
				}).(pulumi.StringPtrOutput)),
			},
		})
		if err != nil {
			return err
		}
		return nil
	})
}

```

## Import

This resource can be imported with the `create_duration` and `destroy_duration`, separated by a comma (`,`).

e.g. For 30 seconds create duration with no destroy duration:

```sh $ pulumi import time:index/sleep:Sleep example 30s, ```

e.g. For 30 seconds destroy duration with no create duration:

```sh $ pulumi import time:index/sleep:Sleep example ,30s ```

The `triggers` argument cannot be imported.

func GetSleep added in v0.0.16

func GetSleep(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *SleepState, opts ...pulumi.ResourceOption) (*Sleep, error)

GetSleep gets an existing Sleep resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewSleep added in v0.0.16

func NewSleep(ctx *pulumi.Context,
	name string, args *SleepArgs, opts ...pulumi.ResourceOption) (*Sleep, error)

NewSleep registers a new resource with the given unique name, arguments, and options.

func (*Sleep) ElementType added in v0.0.16

func (*Sleep) ElementType() reflect.Type

func (*Sleep) ToSleepOutput added in v0.0.16

func (i *Sleep) ToSleepOutput() SleepOutput

func (*Sleep) ToSleepOutputWithContext added in v0.0.16

func (i *Sleep) ToSleepOutputWithContext(ctx context.Context) SleepOutput

type SleepArgs added in v0.0.16

type SleepArgs struct {
	// [Time duration](https://golang.org/pkg/time/#ParseDuration) to delay resource creation. For example, `30s` for 30 seconds or `5m` for 5 minutes. Updating this value by itself will not trigger a delay.
	CreateDuration  pulumi.StringPtrInput
	DestroyDuration pulumi.StringPtrInput
	// (Optional) Arbitrary map of values that, when changed, will run any creation or destroy delays again. See the main provider documentation for more information.
	Triggers pulumi.StringMapInput
}

The set of arguments for constructing a Sleep resource.

func (SleepArgs) ElementType added in v0.0.16

func (SleepArgs) ElementType() reflect.Type

type SleepArray added in v0.0.16

type SleepArray []SleepInput

func (SleepArray) ElementType added in v0.0.16

func (SleepArray) ElementType() reflect.Type

func (SleepArray) ToSleepArrayOutput added in v0.0.16

func (i SleepArray) ToSleepArrayOutput() SleepArrayOutput

func (SleepArray) ToSleepArrayOutputWithContext added in v0.0.16

func (i SleepArray) ToSleepArrayOutputWithContext(ctx context.Context) SleepArrayOutput

type SleepArrayInput added in v0.0.16

type SleepArrayInput interface {
	pulumi.Input

	ToSleepArrayOutput() SleepArrayOutput
	ToSleepArrayOutputWithContext(context.Context) SleepArrayOutput
}

SleepArrayInput is an input type that accepts SleepArray and SleepArrayOutput values. You can construct a concrete instance of `SleepArrayInput` via:

SleepArray{ SleepArgs{...} }

type SleepArrayOutput added in v0.0.16

type SleepArrayOutput struct{ *pulumi.OutputState }

func (SleepArrayOutput) ElementType added in v0.0.16

func (SleepArrayOutput) ElementType() reflect.Type

func (SleepArrayOutput) Index added in v0.0.16

func (SleepArrayOutput) ToSleepArrayOutput added in v0.0.16

func (o SleepArrayOutput) ToSleepArrayOutput() SleepArrayOutput

func (SleepArrayOutput) ToSleepArrayOutputWithContext added in v0.0.16

func (o SleepArrayOutput) ToSleepArrayOutputWithContext(ctx context.Context) SleepArrayOutput

type SleepInput added in v0.0.16

type SleepInput interface {
	pulumi.Input

	ToSleepOutput() SleepOutput
	ToSleepOutputWithContext(ctx context.Context) SleepOutput
}

type SleepMap added in v0.0.16

type SleepMap map[string]SleepInput

func (SleepMap) ElementType added in v0.0.16

func (SleepMap) ElementType() reflect.Type

func (SleepMap) ToSleepMapOutput added in v0.0.16

func (i SleepMap) ToSleepMapOutput() SleepMapOutput

func (SleepMap) ToSleepMapOutputWithContext added in v0.0.16

func (i SleepMap) ToSleepMapOutputWithContext(ctx context.Context) SleepMapOutput

type SleepMapInput added in v0.0.16

type SleepMapInput interface {
	pulumi.Input

	ToSleepMapOutput() SleepMapOutput
	ToSleepMapOutputWithContext(context.Context) SleepMapOutput
}

SleepMapInput is an input type that accepts SleepMap and SleepMapOutput values. You can construct a concrete instance of `SleepMapInput` via:

SleepMap{ "key": SleepArgs{...} }

type SleepMapOutput added in v0.0.16

type SleepMapOutput struct{ *pulumi.OutputState }

func (SleepMapOutput) ElementType added in v0.0.16

func (SleepMapOutput) ElementType() reflect.Type

func (SleepMapOutput) MapIndex added in v0.0.16

func (SleepMapOutput) ToSleepMapOutput added in v0.0.16

func (o SleepMapOutput) ToSleepMapOutput() SleepMapOutput

func (SleepMapOutput) ToSleepMapOutputWithContext added in v0.0.16

func (o SleepMapOutput) ToSleepMapOutputWithContext(ctx context.Context) SleepMapOutput

type SleepOutput added in v0.0.16

type SleepOutput struct{ *pulumi.OutputState }

func (SleepOutput) CreateDuration added in v0.0.16

func (o SleepOutput) CreateDuration() pulumi.StringPtrOutput

[Time duration](https://golang.org/pkg/time/#ParseDuration) to delay resource creation. For example, `30s` for 30 seconds or `5m` for 5 minutes. Updating this value by itself will not trigger a delay.

func (SleepOutput) DestroyDuration added in v0.0.16

func (o SleepOutput) DestroyDuration() pulumi.StringPtrOutput

func (SleepOutput) ElementType added in v0.0.16

func (SleepOutput) ElementType() reflect.Type

func (SleepOutput) ToSleepOutput added in v0.0.16

func (o SleepOutput) ToSleepOutput() SleepOutput

func (SleepOutput) ToSleepOutputWithContext added in v0.0.16

func (o SleepOutput) ToSleepOutputWithContext(ctx context.Context) SleepOutput

func (SleepOutput) Triggers added in v0.0.16

func (o SleepOutput) Triggers() pulumi.StringMapOutput

(Optional) Arbitrary map of values that, when changed, will run any creation or destroy delays again. See the main provider documentation for more information.

type SleepState added in v0.0.16

type SleepState struct {
	// [Time duration](https://golang.org/pkg/time/#ParseDuration) to delay resource creation. For example, `30s` for 30 seconds or `5m` for 5 minutes. Updating this value by itself will not trigger a delay.
	CreateDuration  pulumi.StringPtrInput
	DestroyDuration pulumi.StringPtrInput
	// (Optional) Arbitrary map of values that, when changed, will run any creation or destroy delays again. See the main provider documentation for more information.
	Triggers pulumi.StringMapInput
}

func (SleepState) ElementType added in v0.0.16

func (SleepState) ElementType() reflect.Type

type Static

type Static struct {
	pulumi.CustomResourceState

	// Number day of timestamp.
	Day pulumi.IntOutput `pulumi:"day"`
	// Number hour of timestamp.
	Hour pulumi.IntOutput `pulumi:"hour"`
	// Number minute of timestamp.
	Minute pulumi.IntOutput `pulumi:"minute"`
	// Number month of timestamp.
	Month pulumi.IntOutput `pulumi:"month"`
	// Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.
	Rfc3339 pulumi.StringOutput `pulumi:"rfc3339"`
	// Number second of timestamp.
	Second pulumi.IntOutput `pulumi:"second"`
	// Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. See the main provider documentation for more information.
	Triggers pulumi.StringMapOutput `pulumi:"triggers"`
	// Number of seconds since epoch time, e.g. `1581489373`.
	Unix pulumi.IntOutput `pulumi:"unix"`
	// Number year of timestamp.
	Year pulumi.IntOutput `pulumi:"year"`
}

## Example Usage

### Basic Usage

```go package main

import (

"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
"github.com/pulumiverse/pulumi-time/sdk/go/time"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		example, err := time.NewStatic(ctx, "example", nil)
		if err != nil {
			return err
		}
		ctx.Export("currentTime", example.Rfc3339)
		return nil
	})
}

```

### Triggers Usage

```go package main

import (

"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/ec2"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
"github.com/pulumiverse/pulumi-time/sdk/go/time"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		amiUpdate, err := time.NewStatic(ctx, "amiUpdate", &time.StaticArgs{
			Triggers: pulumi.StringMap{
				"ami_id": pulumi.Any(data.Aws_ami.Example.Id),
			},
		})
		if err != nil {
			return err
		}
		_, err = ec2.NewInstance(ctx, "server", &ec2.InstanceArgs{
			Ami: pulumi.String(amiUpdate.Triggers.ApplyT(func(triggers map[string]string) (*string, error) {
				return &triggers.AmiId, nil
			}).(pulumi.StringPtrOutput)),
			Tags: pulumi.StringMap{
				"AmiUpdateTime": amiUpdate.Rfc3339,
			},
		})
		if err != nil {
			return err
		}
		return nil
	})
}

```

## Import

This resource can be imported using the UTC RFC3339 value, e.g.

```sh $ pulumi import time:index/static:Static example 2020-02-12T06:36:13Z ```

The `triggers` argument cannot be imported.

func GetStatic

func GetStatic(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *StaticState, opts ...pulumi.ResourceOption) (*Static, error)

GetStatic gets an existing Static resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewStatic

func NewStatic(ctx *pulumi.Context,
	name string, args *StaticArgs, opts ...pulumi.ResourceOption) (*Static, error)

NewStatic registers a new resource with the given unique name, arguments, and options.

func (*Static) ElementType

func (*Static) ElementType() reflect.Type

func (*Static) ToStaticOutput

func (i *Static) ToStaticOutput() StaticOutput

func (*Static) ToStaticOutputWithContext

func (i *Static) ToStaticOutputWithContext(ctx context.Context) StaticOutput

type StaticArgs

type StaticArgs struct {
	// Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.
	Rfc3339 pulumi.StringPtrInput
	// Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. See the main provider documentation for more information.
	Triggers pulumi.StringMapInput
}

The set of arguments for constructing a Static resource.

func (StaticArgs) ElementType

func (StaticArgs) ElementType() reflect.Type

type StaticArray

type StaticArray []StaticInput

func (StaticArray) ElementType

func (StaticArray) ElementType() reflect.Type

func (StaticArray) ToStaticArrayOutput

func (i StaticArray) ToStaticArrayOutput() StaticArrayOutput

func (StaticArray) ToStaticArrayOutputWithContext

func (i StaticArray) ToStaticArrayOutputWithContext(ctx context.Context) StaticArrayOutput

type StaticArrayInput

type StaticArrayInput interface {
	pulumi.Input

	ToStaticArrayOutput() StaticArrayOutput
	ToStaticArrayOutputWithContext(context.Context) StaticArrayOutput
}

StaticArrayInput is an input type that accepts StaticArray and StaticArrayOutput values. You can construct a concrete instance of `StaticArrayInput` via:

StaticArray{ StaticArgs{...} }

type StaticArrayOutput

type StaticArrayOutput struct{ *pulumi.OutputState }

func (StaticArrayOutput) ElementType

func (StaticArrayOutput) ElementType() reflect.Type

func (StaticArrayOutput) Index

func (StaticArrayOutput) ToStaticArrayOutput

func (o StaticArrayOutput) ToStaticArrayOutput() StaticArrayOutput

func (StaticArrayOutput) ToStaticArrayOutputWithContext

func (o StaticArrayOutput) ToStaticArrayOutputWithContext(ctx context.Context) StaticArrayOutput

type StaticInput

type StaticInput interface {
	pulumi.Input

	ToStaticOutput() StaticOutput
	ToStaticOutputWithContext(ctx context.Context) StaticOutput
}

type StaticMap

type StaticMap map[string]StaticInput

func (StaticMap) ElementType

func (StaticMap) ElementType() reflect.Type

func (StaticMap) ToStaticMapOutput

func (i StaticMap) ToStaticMapOutput() StaticMapOutput

func (StaticMap) ToStaticMapOutputWithContext

func (i StaticMap) ToStaticMapOutputWithContext(ctx context.Context) StaticMapOutput

type StaticMapInput

type StaticMapInput interface {
	pulumi.Input

	ToStaticMapOutput() StaticMapOutput
	ToStaticMapOutputWithContext(context.Context) StaticMapOutput
}

StaticMapInput is an input type that accepts StaticMap and StaticMapOutput values. You can construct a concrete instance of `StaticMapInput` via:

StaticMap{ "key": StaticArgs{...} }

type StaticMapOutput

type StaticMapOutput struct{ *pulumi.OutputState }

func (StaticMapOutput) ElementType

func (StaticMapOutput) ElementType() reflect.Type

func (StaticMapOutput) MapIndex

func (StaticMapOutput) ToStaticMapOutput

func (o StaticMapOutput) ToStaticMapOutput() StaticMapOutput

func (StaticMapOutput) ToStaticMapOutputWithContext

func (o StaticMapOutput) ToStaticMapOutputWithContext(ctx context.Context) StaticMapOutput

type StaticOutput

type StaticOutput struct{ *pulumi.OutputState }

func (StaticOutput) Day

func (o StaticOutput) Day() pulumi.IntOutput

Number day of timestamp.

func (StaticOutput) ElementType

func (StaticOutput) ElementType() reflect.Type

func (StaticOutput) Hour

func (o StaticOutput) Hour() pulumi.IntOutput

Number hour of timestamp.

func (StaticOutput) Minute

func (o StaticOutput) Minute() pulumi.IntOutput

Number minute of timestamp.

func (StaticOutput) Month

func (o StaticOutput) Month() pulumi.IntOutput

Number month of timestamp.

func (StaticOutput) Rfc3339

func (o StaticOutput) Rfc3339() pulumi.StringOutput

Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.

func (StaticOutput) Second

func (o StaticOutput) Second() pulumi.IntOutput

Number second of timestamp.

func (StaticOutput) ToStaticOutput

func (o StaticOutput) ToStaticOutput() StaticOutput

func (StaticOutput) ToStaticOutputWithContext

func (o StaticOutput) ToStaticOutputWithContext(ctx context.Context) StaticOutput

func (StaticOutput) Triggers

func (o StaticOutput) Triggers() pulumi.StringMapOutput

Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. See the main provider documentation for more information.

func (StaticOutput) Unix

func (o StaticOutput) Unix() pulumi.IntOutput

Number of seconds since epoch time, e.g. `1581489373`.

func (StaticOutput) Year

func (o StaticOutput) Year() pulumi.IntOutput

Number year of timestamp.

type StaticState

type StaticState struct {
	// Number day of timestamp.
	Day pulumi.IntPtrInput
	// Number hour of timestamp.
	Hour pulumi.IntPtrInput
	// Number minute of timestamp.
	Minute pulumi.IntPtrInput
	// Number month of timestamp.
	Month pulumi.IntPtrInput
	// Base timestamp in [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339#section-5.8) format (see [RFC3339 time string](https://tools.ietf.org/html/rfc3339#section-5.8) e.g., `YYYY-MM-DDTHH:MM:SSZ`). Defaults to the current time.
	Rfc3339 pulumi.StringPtrInput
	// Number second of timestamp.
	Second pulumi.IntPtrInput
	// Arbitrary map of values that, when changed, will trigger a new base timestamp value to be saved. See the main provider documentation for more information.
	Triggers pulumi.StringMapInput
	// Number of seconds since epoch time, e.g. `1581489373`.
	Unix pulumi.IntPtrInput
	// Number year of timestamp.
	Year pulumi.IntPtrInput
}

func (StaticState) ElementType

func (StaticState) ElementType() reflect.Type

Directories

Path Synopsis

Jump to